@@ -10,33 +10,33 @@
 # ************************************************************************
 # ************************************************************************
 
-lingini <- function(Y, id = NULL, weight = NULL, sort = NULL, 
-                    Dom = NULL, period=NULL, dataset = NULL,
-                    var_name="lin_gini") {
+lingini <- function(Y, id = NULL, weight = NULL,  
+                    sort = NULL, Dom = NULL, period = NULL,
+                    dataset = NULL, var_name = "lin_gini") {
 
    ## initializations
-   if (min(dim(as.data.frame(var_name))==1)!=1) {
+   if (min(dim(as.data.frame(var_name)) == 1) != 1) {
        stop("'var_name' must have defined name of the linearized variable")}
 
    if (!is.null(dataset)) {
        dataset <- data.table(dataset) 
-       if (checker(Y, dataset, "Y")) Y <- dataset[, Y, with=FALSE] 
+       if (checker(Y, dataset, "Y")) Y <- dataset[, Y, with = FALSE] 
 
        if (!is.null(id)) {
-            if (checker(id, dataset, "id")) id <- dataset[, id, with=FALSE]}
+            if (checker(id, dataset, "id")) id <- dataset[, id, with = FALSE]}
 
        if(!is.null(weight)) {
-           if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with=FALSE] }
+           if (checker(weight, dataset, "weight")) weight <- dataset[, weight, with = FALSE] }
 
        if(!is.null(sort)) {
-           if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with=FALSE] }
+           if (checker(sort, dataset, "sort")) sort <- dataset[, sort, with = FALSE] }
 
        if (!is.null(period)) { 
-            if (min(period %in% names(dataset))!=1) stop("'period' does not exist in 'dataset'!")
-            if (min(period %in% names(dataset))==1) period <- dataset[, period, with=FALSE] }
+            if (min(period %in% names(dataset)) != 1) stop("'period' does not exist in 'dataset'!")
+            if (min(period %in% names(dataset)) == 1) period <- dataset[, period, with = FALSE] }
 
        if (!is.null(Dom)) {
-            if (checker(Dom,dataset,"Dom")) Dom <- dataset[, Dom, with=FALSE] }
+            if (checker(Dom, dataset, "Dom")) Dom <- dataset[, Dom, with = FALSE] }
 
      } 
 
@@ -45,7 +45,7 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
    Y <- data.frame(Y)
    n <- nrow(Y)
    if (ncol(Y) != 1) stop("'Y' must be a vector or 1 column data.frame, matrix, data.table")
-   Y <- Y[,1]
+   Y <- Y[, 1]
    if(!is.numeric(Y)) stop("'Y' must be numeric")
    if (any(is.na(Y))) stop("'Y' has missing values")
 
@@ -54,7 +54,7 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
    if (is.null(weight)) weight <- data.frame(rep.int(1, n))
    if (nrow(weight) != n) stop("'weight' must be the same length as 'Y'")
    if (ncol(weight) != 1) stop("'weight' must be a vector or 1 column data.frame, matrix, data.table")
-   weight <- weight[,1]
+   weight <- weight[, 1]
    if (!is.numeric(weight)) stop("'weight' must be numeric")
    if (any(is.na(weight))) stop("'weight' has missing values")
 
@@ -73,17 +73,17 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
                  stop("'period' are duplicate column names: ", 
                       paste(names(period)[duplicated(names(period))], collapse = ","))
        if (nrow(period) != n) stop("'period' must be the same length as 'Y'")
-       period[, (names(period)):=lapply(.SD, as.character)]
+       period[, (names(period)) := lapply(.SD, as.character)]
        if(any(is.na(period))) stop("'period' has missing values")
    }   
 
    # id
-   if (is.null(id)) id <- 1:n
+   if (is.null(id)) id <- 1 : n
    id <- data.table(id)
    if (any(is.na(id))) stop("'id' has missing values")
    if (ncol(id) != 1) stop("'id' must be 1 column data.frame, matrix, data.table")
    if (nrow(id) != n) stop("'id' must be the same length as 'Y'")
-   if (is.null(names(id))||(names(id)=="id")) setnames(id,names(id),"ID")
+   if (is.null(names(id)) | (names(id) == "id")) setnames(id, names(id), "ID")
    if (is.null(period)){ if (any(duplicated(id))) stop("'id' are duplicate values") 
                        } else {
                           id1 <- data.table(period, id)
@@ -98,7 +98,7 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
                       paste(names(Dom)[duplicated(names(Dom))], collapse = ","))
              if (is.null(names(Dom))) stop("'Dom' must have column names")
              if (nrow(Dom) != n) stop("'Dom' must be the same length as 'Y'")
-             Dom[, (names(Dom)):=lapply(.SD, as.character)]
+             Dom[, (names(Dom)) := lapply(.SD, as.character)]
              if (any(is.na(Dom))) stop("'Dom' has missing values")
              if (any(grepl("__", names(Dom)))) stop("'Dom' is not allowed column names with '__'")
        }
@@ -108,7 +108,7 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
    period_agg <- period1 <- NULL
    if (!is.null(period)) { period1 <- copy(period)
                            period_agg <- data.table(unique(period))
-                       } else period1 <- data.table(ind=ind0)
+                       } else period1 <- data.table(ind = ind0)
    period1_agg <- data.table(unique(period1))
    
    # Gini by domain (if requested)
@@ -121,30 +121,34 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
 
         Gini <- c()
         gini_m <- copy(gini_id)
-        for(i in 1:nrow(Dom_agg)) {
+        for(i in 1 : nrow(Dom_agg)) {
             g <- c(var_name, paste(names(Dom), as.matrix(Dom_agg[i,]), sep = "."))
             var_nams <- do.call(paste, as.list(c(g, sep="__")))
             indi <- (rowSums(Dom == Dom_agg[i,][ind0,]) == ncol(Dom))
 
-            gini_l <- lapply(1:nrow(period1_agg), function(j) {
-               indj <- ((rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))&(indi))
+            gini_l <- lapply(1 : nrow(period1_agg), function(j) {
+               indj <- ((rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1)) & (indi))
                if (!is.null(period)) { rown <- cbind(period_agg[j], Dom_agg[i])
                                      } else rown <- Dom_agg[i] 
-               ginil <- linginiCalc(x=Y[indj], ids=gini_id[indj],
-                                    weights=weight[indj], sort=sort[indj])
+               ginil <- linginiCalc(x = Y[indj], 
+                                    ids = gini_id[indj],
+                                    weights = weight[indj],
+                                    sort=sort[indj])
                list(data.table(rown, ginil$Gini), ginil$lin)
               })
 
             giniv <- rbindlist(lapply(gini_l, function(x) x[[1]]))
             ginilin <- rbindlist(lapply(gini_l, function(x) x[[2]]))
             setnames(ginilin, names(ginilin), c(names(gini_id), var_nams))
-            gini_m <- merge(gini_m, ginilin, all=TRUE, by=names(gini_id))
+            gini_m <- merge(gini_m, ginilin, all = TRUE, by = names(gini_id))
             Gini <- rbind(Gini, giniv)
          }
-     } else { gini_l <- lapply(1:nrow(period1_agg), function(j) {
+     } else { gini_l <- lapply(1 : nrow(period1_agg), function(j) {
                            indj <- (rowSums(period1 == period1_agg[j,][ind0,]) == ncol(period1))
-                           ginil <- linginiCalc(x=Y[indj], ids=gini_id[indj],
-                                                weights=weight[indj], sort=sort[indj])                                                 
+                           ginil <- linginiCalc(x = Y[indj],
+                                                ids = gini_id[indj],
+                                                weights = weight[indj],
+                                                sort = sort[indj])                                                 
                            if (!is.null(period)) {
                                   list(data.table(period_agg[j], ginil$Gini), ginil$lin)
                                 }  else ginil
@@ -155,7 +159,7 @@ lingini <- function(Y, id = NULL, weight = NULL, sort = NULL,
      }
     gini_m[is.na(gini_m)] <- 0
     setkeyv(gini_m, names(gini_id))
-    return(list(value=Gini, lin=gini_m))
+    return(list(value = Gini, lin = gini_m))
 }
 
 
@@ -176,29 +180,29 @@ linginiCalc <- function(x, ids, weights = NULL, sort = NULL) {
     cw <- cumsum(weights)   # cumulative sum of weights
     T<- sum(wx)             # Estimated total income
 
-    Num_eu <- 2 * sum(wx*cw) - sum(weights^2 * x)
-    Num <- sum((2*cw-1)*wx)
-    Den <- N*T;
+    Num_eu <- 2 * sum(wx * cw) - sum(weights^2 * x)
+    Num <- sum((2 * cw - 1) * wx)
+    Den <- N * T;
 
-    Gini_eu <- 100*(Num_eu/Den-1)
-    Gini <- Num/Den-1
+    Gini_eu <- 100 * (Num_eu / Den - 1)
+    Gini <- Num / Den - 1
     Gini_pr <- 100 * Gini
 
     # COMPUTATION OF A LINEARIZED VARIABLE
 
-    F <- cumsum(weights/N)   #  Estimation of the cumulative distribution function
+    F <- cumsum(weights / N)   #  Estimation of the cumulative distribution function
     G <- cumsum(wx)            #  Weighted partial sum
 
     # LINEARIZED VARIABLE OF THE GINI COEFFICIENT (IN %)
 
-    lin <- 100*(2*(T-G+wx+N*(x*F))-x-(Gini+1)*(T+N*x))/(N*T)
+    lin <- 100 * (2 * (T - G + wx + N * (x * F)) - x - (Gini + 1) * (T + N * x)) / (N * T)
 
     if (is.nan(Gini))  Gini_pr <- lin <- 0
     
-    Gini_pr <- data.table(Gini=Gini_pr, Gini_eu=Gini_eu)
+    Gini_pr <- data.table(Gini = Gini_pr, Gini_eu = Gini_eu)
 
-    lin_id <- data.table(ids,lin)
+    lin_id <- data.table(ids, lin)
 
-    return(list(Gini=Gini_pr, lin=lin_id))
+    return(list(Gini = Gini_pr, lin = lin_id))
 }
 
