@@ -223,7 +223,7 @@ linQSRCalc<-function(income, ids, weights = NULL, sort = NULL, ind = NULL, alpha
        # 1. Linearization of the bottom quantile 
  
        u1 <- (quant_inf - income) / h;
-       vect_f1 <- exp(-(u1^2) / 2)/sqrt(2 * pi)
+       vect_f1 <- exp(-(u1^2) / 2) / sqrt(2 * pi)
        f_quant1 <- sum(vect_f1 * wght) / (N * h) 
 
        lin_inf <- -(1 / N) * ((income <= quant_inf) - alpha / 100) / f_quant1
@@ -232,28 +232,28 @@ linQSRCalc<-function(income, ids, weights = NULL, sort = NULL, ind = NULL, alpha
        # 2. Linearization of the top quantile 
  
        u2 <- (quant_sup - income) / h
-       vect_f2 <- exp(-(u2^2) / 2)/sqrt(2 * pi)
-       f_quant2 <- sum(vect_f2 * wght)/(N * h)
+       vect_f2 <- exp( - (u2^2) / 2) / sqrt(2 * pi)
+       f_quant2 <- sum(vect_f2 * wght) / (N * h)
 
-       lin_sup <- -(1/N)*((income<=quant_sup)-alpha2/100)/f_quant2 
+       lin_sup <- - (1 / N) * ((income <= quant_sup) - alpha2 / 100) / f_quant2 
 
 
        # 3. Linearization of the total income for the top quintile
   
        u3 <- (quant_sup - income) / h
-       vect_f3 <- exp(-(u3^2) / 2)/sqrt(2 * pi)
+       vect_f3 <- exp(- (u3^2) / 2) / sqrt(2 * pi)
        f_quant3 <- sum(vect_f3 * v) / h
  
-       lin_num <- income - income * (income <= quant_sup) - f_quant3 * lin_sup
+       lin_num <- ind * (income - income * (income <= quant_sup) - f_quant3 * lin_sup)
  
 
        # 4. Linearization of the total income for the bottom quintile 
   
        u4 <- (quant_inf - income) / h
-       vect_f4 <- exp(-(u4^2) / 2) / sqrt(2 * pi)
+       vect_f4 <- exp( - (u4^2) / 2) / sqrt(2 * pi)
        f_quant4 <- sum(vect_f4 * v) / h
  
-       lin_den <- income * (income <= quant_inf) + f_quant4 * lin_inf
+       lin_den <- ind * (income * (income <= quant_inf) + f_quant4 * lin_inf)
 
       #****************************************************************************
       #                 LINEARIZED VARIABLE OF THE QUANTILE SHARE RATIO                  
